<?php
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM - Open Source CRM application.
 * Copyright (C) 2014  Yuri Kuznetsov, Taras Machyshyn, Oleksiy Avramenko
 * Website: http://www.espocrm.com
 *
 * EspoCRM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EspoCRM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EspoCRM. If not, see http://www.gnu.org/licenses/.
 ************************************************************************/

class AfterUpgrade
{
    public function run($container)
    {
        $config = $container->get('config');
        $config->set('adminNotifications', true);
        $config->set('adminNotificationsNewVersion', true);
        $config->set('adminNotificationsCronIsNotConfigured', true);
        $languageList = $config->get('languageList', []);
        if (!in_array('lt_LT', $languageList)) {
            $languageList[] = 'lt_LT';
        }
        $config->set('languageList', $languageList);
        $config->save();


        $followCreatedEntities = $container->get('config')->get('followCreatedEntities');
        if ($followCreatedEntities) {
            $entityManager = $container->get('entityManager');

            $userList = $entityManager->getRepository('User')->where([
                'isActive' => true,
                'id' != 'system'
            ])->find();
            foreach ($userList as $user) {
                $preferences = $entityManager->getEntity('Preferences', $user->id);
                $preferences->set('followCreatedEntities', true);
                $entityManager->saveEntity($preferences);
            }
        }


        $metadata = $container->get('metadata');
        $pdo = $container->get('entityManager')->getPDO();

        $query = "
            UPDATE `attachment`
            SET role = 'Attachment'
            WHERE
                role IS NULL
                AND
                source_id IS NOT NULL
                AND
                deleted = 0
        ";
        $pdo->query($query);

        $query = "
            UPDATE `attachment`
            SET role = 'Attachment'
            WHERE
                parent_id IS NOT NULL
                AND
                role IS NULL
                AND
                deleted = 0
        ";
        $pdo->query($query);

        $entityDefs = $metadata->get(['entityDefs']);
        foreach ($entityDefs as $scope => $defs) {
            $fieldDefs = $metadata->get(['entityDefs', $scope, 'fields'], array());
            foreach ($fieldDefs as $field => $item) {
                if (empty($item['type'])) continue;
                if ($item['type'] === 'attachmentMultiple') {
                    $query = "
                        UPDATE `attachment`
                        SET field = ".$pdo->quote($field)."
                        WHERE
                            field IS NULL
                            AND
                            parent_type = ".$pdo->quote($scope)."
                            AND
                            role = 'Attachment'
                            AND
                            deleted = 0
                    ";
                    $pdo->query($query);
                }
            }
        }


        $entityManager = $container->get('entityManager');

        $job = $entityManager->getEntity('Job');
        $dt = new \DateTime();
        $dt->modify('+3 minutes');
        $job->set([
            'serviceName' => 'App',
            'methodName' => 'jobRebuild',
            'method' => 'jobRebuild',
            'executeTime' => $dt->format('Y-m-d H:i:s')
        ]);
        $entityManager->saveEntity($job);
    }
}
